#! /bin/bash

# Copyright (C) 2014  Cedric hertault, knackko@gmail.com

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>. 

VERSION="ODSsync2 v1.11-blender"
DIALOG="dialog "
RSYNC="rsync --info=name,progress --stats -ztrh "
RSYNC_SIG="rsync -ztrh "
LOG_FILE="logs/odssync.log"
LOG_RSYNC="logs/rsync.log"
rsyncd_host="212.129.50.82"
rsyncd_module="2014"
tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/test$$
trap "rm -f $tempfile" 0 1 2 5 15
CURPATH=`pwd`
INFO=2
ERROR=1
LOG_LEVEL=2

cd ../
RFACTOR_PATH=`pwd`
cd ../
INSTALL_PATH=`pwd`
cd "$CURPATH"

sync_state1="OFF"
sync_state2="OFF"
sync_state3="OFF"
sync_state4="OFF"
ui_state1="ON"
ui_state2="OFF"
lang=EN
MD5_UPDATE=""
UPDATE_ENABLE=1 # set to 0 in params file if needed by dev
UI="rfactor"

export RSYNC_PASSWORD="na"
export LOGNAME="syncuser"
export DIALOGRC="$CURPATH/dialogrc"
		
# DEBUT FONCTIONS
if [ -f "$CURPATH/params" ]
then
	. "$CURPATH/params"
fi

# recuperation du pilote actif dans l'installation

trap 'rapporter_erreur 4 $LINENO $?' ERR
plrfiles=`/bin/find.exe "$RFACTOR_PATH/UserData/" -type f -name "*.plr" -o -name "*.PLR" | tail -n 1 | tr -d '\r'`
if [ -n "$plrfiles" ]
then
	last_plr=`ls -1rt "$plrfiles" | tail -n 1 | tr -d '\r'`
	plr_filename=`echo ${last_plr##*/}`
	drivername=`echo ${plr_filename%%.*}`
	last_multiplayer="$RFACTOR_PATH/UserData/$drivername/Multiplayer.ini"
fi
trap - ERR  
rfe=""

rapporter_erreur(){
	code_erreur=$1
	ligne=$2
	code=$3
	

	case $code_erreur in
	1)# echec de synchronisation
		error "erreur 1: echec synchronisation, code $code, ligne $ligne"
		message="$message_erreur1, code:$code l:$ligne"
		creer_ziplog
	;;
	2)# echec de verification d'une signature
		error "erreur 2: echec de verification de signature, code $code, ligne $ligne"
		message="$message_erreur2, code:$code l:$ligne"
		creer_ziplog
	;;
	3)# erreur durant l'installation du mod
		error "erreur 3: erreur durant l'installation du mod,  code $code, ligne $ligne"
		message="$message_erreur3, code:$code l:$ligne"
		creer_ziplog
	;;
	4)# erreur durant la detection du profil actif
		error "erreur 4: la detection du profil actif,  code $code, ligne $ligne"
		message="$message_erreur4, code:$code l:$ligne"
		creer_ziplog
	;;
	11)# installation sous C:
		error "erreur 11: installation sous C:"
		message="$message_erreur11"
	;;
	12)# rfactor lance
		error "erreur 12: rfactor lance"
		message="$message_erreur12"
	;;
	13)# installation sous C:Program Files
		error "erreur 13: installation sous C:Program Files"
		message="$message_erreur11"
	;;
	esac
	
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
	--title "\Z1$erreur_title\Zn" --clear --trim --cr-wrap\
	--colors  --ok-label "$quitter" \
	--msgbox "\n\Zb\Z1! $message !\Zn" 12 70 2> $tempfile
	sortir
}

creer_ziplog(){
	zipname=ODSsync2_${drivername}_`date +"%Y%m%d-%H%M%S"`.zip
	zip -q "ziplogs/$zipname" logs/*
	
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
	--title "\Z1$ziplog_title\Zn" --clear --trim --cr-wrap\
	--colors   \
	--msgbox "$message_logs$zipname" 12 70 2> $tempfile
	
}

info(){
   if [ "$LOG_LEVEL" -eq $INFO ]
	then
		echo "$(date +"%Y/%m/%d %H:%M:%S") [INFO] $@" >> $LOG_FILE
	fi
}

error(){
	echo "$(date +"%Y/%m/%d %H:%M:%S") [ERROR] $@" >> $LOG_FILE
}

charger_langue(){
    if [ "$lang" = "FR" ]
    then
        . "$CURPATH/FR"
    fi
    if [ "$lang" = "EN" ]
    then
        . "$CURPATH/EN"
    fi
	info "Langue $lang chargee"
}

about(){
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$intro_title" --clear --trim --cr-wrap\
		--msgbox "$about" 28 95 2> $tempfile
		
				#--no-cancel  \
		#--exit-label "OK" \
		#--textbox "$CURPATH/$about" 15 95 2> $tempfile
}

verifier_mdp(){	
	info "Verification du mot de passe"
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
	--title "$patience" \
	--infobox "\n$mdp1" 5 61 2> $tempfile
	
	rsync -q rsync://$rsyncd_host:/2014
	retval=$?
	if [ $retval -eq 5 ]
	then
		error "Mot de passe errone"
		if [ "$RSYNC_PASSWORD"="na" ]
		then
			choisir_langue
		fi
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
			--title "$mdp_title" --clear \
			--cancel-label "$quitter" \
			--inputbox "\n\n$mdp_text  " 20 61 2> $tempfile
		retval=$?

		case $retval in
		  0)
			RSYNC_PASSWORD=`cat $tempfile`
			verifier_mdp;;
		  1)
			sortir;;
		  255)
			sortir;;
		esac
	else
		info "Mot de passe accepte"
	fi
}

changer_rfe(){
	case $1 in
	0) 
		info "Activation RFE"
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$rfe_title" \
		--infobox "\n$rfe1" 5 61 2> $tempfile
		mv "$RFACTOR_PATH/Plugins/RFETire.dll.bak" "$RFACTOR_PATH/Plugins/RFETire.dll"
		mv "$RFACTOR_PATH/Plugins/RFETrack.dll.bak" "$RFACTOR_PATH/Plugins/RFETrack.dll"
		mv "$RFACTOR_PATH/Plugins/RFEWeather.dll.bak" "$RFACTOR_PATH/Plugins/RFEWeather.dll"
	;;
	1)	
		info "Desactivation RFE"
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$rfe_title" \
		--infobox "\n$rfe2" 5 61 2> $tempfile
		mv "$RFACTOR_PATH/Plugins/RFETire.dll" "$RFACTOR_PATH/Plugins/RFETire.dll.bak"
		mv "$RFACTOR_PATH/Plugins/RFETrack.dll" "$RFACTOR_PATH/Plugins/RFETrack.dll.bak"
		mv "$RFACTOR_PATH/Plugins/RFEWeather.dll" "$RFACTOR_PATH/Plugins/RFEWeather.dll.bak"
	;;
	[8-9])
		info "Installation RFE"
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$rfe_title" \
		--infobox "\n$rfe3" 5 61 2> $tempfile
		$RSYNC_SIG --log-file=$LOG_RSYNC --files-from=:Packs/RFE.sync rsync://$rsyncd_host:/$rsyncd_module/mods/ODS_Blender "$RFACTOR_PATH"
	;;
	esac
	rfe=`rfe_etat;echo $?`
	menu_principal
}
rfe_etat(){
	#verifier_signature '4.md5'
	if [ -f "$RFACTOR_PATH/Plugins/RFETire.dll"  ] && [ -f "$RFACTOR_PATH/Plugins/RFETire.dll"  ] && [ -f "$RFACTOR_PATH/Plugins/RFEWeather.dll" ]
	then
		is_rfe12=`verifier_signature '4.md5'; echo $? `
		if [ "$is_rfe12" -eq 0 ]
		then
			info "RFE 1.2 actif"
			return 1
		else
			error "RFE mauvaise version"
			return 8
		fi
	else
		if [ -f "$RFACTOR_PATH/Plugins/RFETire.dll.bak"  ] && [ -f "$RFACTOR_PATH/Plugins/RFETire.dll.bak"  ] && [ -f "$RFACTOR_PATH/Plugins/RFEWeather.dll.bak" ]
		then
			info "RFE inactif"
			return 0
		else
			info "RFE non installe"
			return 9
		fi
	fi
}

menu_principal(){
charger_langue


case $rfe in
0)rfe_action="$rfe_etat0 ($rfe_action0)";;
1)rfe_action="$rfe_etat1 ($rfe_action1)";;
8)rfe_action="$rfe_etat8 ($rfe_action8)";;
9)rfe_action="$rfe_etat9 ($rfe_action9)";;
esac


$DIALOG --cancel-label "$quitter" --backtitle "$backtitle                                                     $VERSION" \
    --colors --title "$menu_principal_title" --clear \
        --menu "\n\n$menu_principal1" 20 65 7 \
        "Sync"  "$menu_item1" \
        "Addons"    "$menu_item2" \
        "RFE" "$rfe_action " \
		"Tools" "$menu_item3" \
        "Changelog"    "$menu_item4" \
        "Lang"    "$menu_item5"       \
		"About" "$menu_item6" 2> $tempfile

retval=$?

choice=`cat $tempfile`
case $retval in
  0)
    case "$choice" in
    "Sync")
        synchroniser;;
    "Addons")
        installer_addons;;
    "RFE")
        changer_rfe $rfe;;
	"Tools")
		menu_outils;;
    "Changelog")
        afficher_changelog;;
    "Lang")
        changer_langue	
		menu_principal;;
	"About")
		about
		menu_principal;;
    esac;;
  1)
    sortir;;
  255)
    sortir;;
esac

}

menu_outils(){

$DIALOG --cancel-label "$retour" --backtitle "$backtitle                                                     $VERSION" \
    --colors --title "$menu_outil_title" --clear \
        --menu "\n\n$menu_outil1" 20 61 7 \
        "Ziplog"  "$menuoutil_item1" \
        "Plr"    "$menuoutil_item2" \
		"Multiplayer" "$menuoutil_item3" \
		"UI" "$menuoutil_item4" 2> $tempfile

retval=$?

choice=`cat $tempfile`
case $retval in
  0)
    case "$choice" in
    "Ziplog")
		creer_ziplog
		menu_principal
        ;;
    "Plr")
		dialog --backtitle "$backtitle                                                     $VERSION" \
		--cancel-label "$retour" --title "$menu_outil_title" --colors \
		--form "\n$menu_outil_plr \Zr\Z0$drivername\Zn" 25 80 15 \
		"Headlights On Cars (1 to activate) :" 1 1 "`gawk -F '=' '/Headlights On Cars/ { print $2 }' "$last_plr" | gawk -F '"' '{ print $2 }'`" 1 50 2 1  \
		"Max Headlights (min=2, <8):" 2 1 "`gawk -F '=' '/Max Headlights/ { print $2 }' "$last_plr" | gawk -F '"' '{ print $2 }'`" 2 50 3 2 \
		"Virtual Mirror In Cockpit (1 to activate) :" 4 1 "`gawk -F '=' '/Virtual Rearview In Cockpit/ { print $2 }' "$last_plr" | gawk -F '"' '{ print $2 }'`" 4 50 2 1 \
		"Mirrors (1=center&side,2=center,3=sides) :" 5 1 "`gawk -F '=' '/Rearview/ { print $2 }' "$last_plr" | gawk -F '"' '{ print $2 }'`" 5 50 2 1 2>/tmp/form.1
		
		retval=$?

		choice=`cat $tempfile`
		case $retval in
		  0)
			value1=`head -1 /tmp/form.1 | tail -1`
			value2=`head -2 /tmp/form.1 | tail -1`
			value3=`head -3 /tmp/form.1 | tail -1`
			value4=`head -4 /tmp/form.1 | tail -1`

			gawk -F '"'  -v val="$value1" '/Headlights On Cars=/ { sub($2, val); print; next}1' "$last_plr" > "tmp/$plr_filename.1"
			gawk -F '"'  -v val="$value2" '/Max Headlights=/ { sub($2, val); print; next}1' "tmp/$plr_filename.1" > "tmp/$plr_filename.2"
			gawk -F '"'  -v val="$value3" '/Virtual Rearview In Cockpit=/ { sub($2, val); print; next}1' "tmp/$plr_filename.2" > "tmp/$plr_filename.3"
			gawk -F '"'  -v val="$value4" '/Rearview=/ { sub($2, val); print; next}1' "tmp/$plr_filename.3" > "tmp/$plr_filename.4"
			mv "tmp/$plr_filename.4" "$last_plr"
			menu_outils;;
		  1)
			menu_outils;;
		  255)
			menu_outils;;
		esac	
		;;
    "Multiplayer")
        dialog --backtitle "$backtitle                                                     $VERSION" \
		--cancel-label "$retour" --title "$menu_outil_title" \
		--form "\n$menu_outil_multiplayer" 25 80 16 \
		"Concurrent Server Updates (1000):" 1 1 "`gawk -F '=' '/Concurrent Server Updates/ { print $2 }' "$last_multiplayer" | gawk -F '"' '{ print $2 }'`" 1 35 5 4 2>/tmp/form.1
		
		retval=$?

		choice=`cat $tempfile`
		case $retval in
		  0)
			value1=`head -1 /tmp/form.1 | tail -1`

			gawk -F '"'  -v val="$value1" '/Concurrent Server Updates/ { sub($2, val); print; next}1' "$last_multiplayer" > "tmp/$drivername_multi.1"
			mv "tmp/$drivername_multi.1" "$last_multiplayer"
			menu_outils;;
		  1)
			menu_outils;;
		  255)
			menu_outils;;
		esac	
		;;
	"UI")
		$DIALOG --ok-label "Synchroniser" --backtitle "$backtitle                                                     $VERSION" \
		--title "$ui_title" --clear \
		--cancel-label "$annuler" \
			--radiolist "\n\n$ui" 20 61 5 \
			"1" "$ui_item2" "$ui_state2" \
			"2" "$ui_item1" "$ui_state1" \
		2> $tempfile
			retval=$?
		
		choice=(`cat $tempfile`)
		case $retval in
		0)
			trap 'rapporter_erreur 1 $LINENO $?' ERR
			ui_state1="OFF"
			ui_state2="OFF"
			for item in ${choice[*]}
			do
				case $item in
				1)
					info "Choix UI rfactor"
					ui_state2="ON"
					UI="RFACTOR"
					$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ui_rfactor.addons rsync://$rsyncd_host:/$rsyncd_module/addons/ui_rfactor "$RFACTOR_PATH"				
					;;
				2)
					info "Choix UI HGTTC"
					ui_state1="ON"
					UI="HGTTC"
					# UI sur 1: HGTTC
					$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ui_hgttc.addons rsync://$rsyncd_host:/$rsyncd_module/addons/ui_hgttc "$RFACTOR_PATH"
					;;

				esac
			done
			menu_outils;;
		  1)
			menu_outils;;
		  255)
			menu_outils;;
		esac	
		;;
    esac;;
  1)
    menu_principal;;
  255)
    sortir;;
esac
}

choisir_langue(){
charger_langue

$DIALOG --cancel-label "$quitter" --backtitle "$backtitle                                                     $VERSION" \
		--ok-label "$changer" \
		--extra-button --extra-label "$continuer"\
    --title "$choisir_langue_title" --clear \
        --menu "\n\n$choisir_langue1" 20 61 2 \
        "Lang"    "$menu_item5"        2> $tempfile

retval=$?

choice=`cat $tempfile`
case $retval in
  0)
    case "$choice" in
      
    "Lang")
        changer_langue
		choisir_langue
    esac;;
  1)
    sortir;;
  255)
    sortir;;
esac

}

blender_preinstall(){
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$blender_preinstall_title" --clear \
		--yes-label "$oui" \
		--no-label "$non" \
		--yesno "\n\n$blender_preinstall1" 15 61 2> $tempfile
	retval=$?

	case $retval in
	  0)
		info "Lancement preinstallation"
		mkdir -p "$RFACTOR_PATH/GameData/Vehicles/HISTORIC GT/HISTORICAL FIA GT/GTC-TC-76/JAVELIN/"
		blender_preinstall_done
		;;
	  1)
		sortir;;
	  255)
		sortir;;
	esac

}

blender_preinstall_done(){
	info "Preinstallation effectuee"
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$blender_preinstall_title" --clear \
		--ok-label "$quitter" \
		--msgbox "\n\n$blender_preinstall_done1" 15 61 2> $tempfile
	retval=$?	
}  

blender_install(){
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$blender_preinstall_title" --clear \
		--yes-label "$oui" \
		--no-label "$non" \
		--yesno "\n\n$blender_install1" 15 61 2> $tempfile
	retval=$?

	case $retval in
	  0)
		info "Lancement installation"
		mv "$RFACTOR_PATH/Gamedata/Sounds/HISTORICGT" "$RFACTOR_PATH/Gamedata/Sounds/ODS_Blender"
		mv "$RFACTOR_PATH/Gamedata/Vehicles/HISTORIC GT" "$RFACTOR_PATH/Gamedata/Vehicles/ODS_Blender"
		$RSYNC_SIG --log-file=$logfile rsync://$rsyncd_host:/$rsyncd_module/mods/ODS_Blender/rFm/ODS_blender.rfm "$RFACTOR_PATH/rFm/ODS_blender.rfm"
		rm -rf "$RFACTOR_PATH/rFm/HISTORIC GT.rfm"
		/bin/find "$RFACTOR_PATH/Gamedata/Vehicles/ODS_Blender/HISTORICAL FIA GT" -type f -name "*.veh" -delete
		blender_install_done
		;;
	  1)
		sortir;;
	  255)
		sortir;;
	esac

}

blender_install_done(){
	info "Installation effectuee"
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$blender_preinstall_title" --clear \
		--msgbox "\n\n$blender_install_done1" 15 61 2> $tempfile
	verifier_mdp
	menu_principal "firsttime"
}

synchroniser_ui(){
			$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ui_"$UI".addons rsync://$rsyncd_host:/$rsyncd_module/addons/ui_"$UI" "$RFACTOR_PATH"
}

synchroniser(){
    $DIALOG --ok-label "Synchroniser" --backtitle "$backtitle                                                     $VERSION" \
    --title "$synchroniser_title" --clear \
	--cancel-label "$annuler" \
        --checklist "\n\n$synchroniser1" 20 61 5 \
        "1" "$sync_item1" "$sync_state1" \
        "2" "$sync_item2" "$sync_state2" \
		"3" "$sync_item3" "$sync_state3" \
		"4" "$sync_item4" "$sync_state4" \
	2> $tempfile
        retval=$?

    choice=(`cat $tempfile`)
    case $retval in
    0)
		trap 'rapporter_erreur 1 $LINENO $?' ERR
        sync_state1="OFF"
        sync_state2="OFF"
		sync_state3="OFF"
		sync_state4="OFF"
        for item in ${choice[*]}
        do
            case $item in
            1)
				info "Lancement synchronisation trophee interligue"
                sync_state1="ON"
				# RSYNC sur 1: 2014 trophée
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_trophy.tracks rsync://$rsyncd_host:/$rsyncd_module/tracks "$RFACTOR_PATH/Gamedata/Locations/"
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_trophy.mod rsync://$rsyncd_host:/$rsyncd_module/mods/ODS_Blender "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/mecanos_vintage.addons rsync://$rsyncd_host:/$rsyncd_module/addons/mecanos_vintage "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ods_shortcuts.addons rsync://$rsyncd_host:/$rsyncd_module/addons/ods_shortcuts "$RFACTOR_PATH"
				synchroniser_ui
				;;
            2)
				info "Lancement synchronisation championnat"
                sync_state2="ON"
				# RSYNC sur 3: 2014 fun
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_championship.tracks rsync://$rsyncd_host:/$rsyncd_module/tracks "$RFACTOR_PATH/Gamedata/Locations/"
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_championship.mod rsync://$rsyncd_host:/$rsyncd_module/mods/ODS_Blender "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/mecanos_vintage.addons rsync://$rsyncd_host:/$rsyncd_module/addons/mecanos_vintage "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ods_shortcuts.addons rsync://$rsyncd_host:/$rsyncd_module/addons/ods_shortcuts "$RFACTOR_PATH"	
				synchroniser_ui
				;;
			3)
				info "Lancement synchronisation fun"
                sync_state3="ON"
				# RSYNC sur 3: 2014 fun
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_fun.tracks rsync://$rsyncd_host:/$rsyncd_module/tracks "$RFACTOR_PATH/Gamedata/Locations/"
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_fun.mod rsync://$rsyncd_host:/$rsyncd_module/mods/ODS_Blender "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/mecanos_vintage.addons rsync://$rsyncd_host:/$rsyncd_module/addons/mecanos_vintage "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ods_shortcuts.addons rsync://$rsyncd_host:/$rsyncd_module/addons/ods_shortcuts "$RFACTOR_PATH"	
				synchroniser_ui
				;;
			4)
				info "Lancement synchronisation fun2"
                sync_state4="ON"
				# RSYNC sur 4: 2014 fun2
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_fun2.tracks rsync://$rsyncd_host:/$rsyncd_module/tracks "$RFACTOR_PATH/Gamedata/Locations/"
				$RSYNC --delete-during --log-file=$LOG_RSYNC --files-from=:Packs/2014_fun2.mod rsync://$rsyncd_host:/$rsyncd_module/mods/ODS_Blender "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/mecanos_vintage.addons rsync://$rsyncd_host:/$rsyncd_module/addons/mecanos_vintage "$RFACTOR_PATH"
				$RSYNC --log-file=$LOG_RSYNC --files-from=:Addons/ods_shortcuts.addons rsync://$rsyncd_host:/$rsyncd_module/addons/ods_shortcuts "$RFACTOR_PATH"	
				synchroniser_ui
				;;
            esac
        done
		trap - ERR  

    ;;
  1)
    menu_principal;;
  255)
    menu_principal;;
	esac

	if [ ${#choice[*]} -ne 0 ]
	then
		info "Synchronisation reussie"	
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
			--title "$synchro_title" --clear \
			--msgbox "\n\n$synchro_reussie_text" 9 40 2> $tempfile
	else
		info "Aucun choix de synchronisation"	
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
			--title "$synchro_title" --clear \
			--msgbox "\n\n$synchro_manquechoix_text" 9 40 2> $tempfile	
	fi
	menu_principal
}

sauver_prefs(){
	info "Sauvegarde des prefs"
	declare -p sync_state1 > "$CURPATH/params"
	declare -p sync_state2 >> "$CURPATH/params"
	declare -p sync_state3 >> "$CURPATH/params"
	declare -p sync_state4 >> "$CURPATH/params"
	declare -p ui_state1 >> "$CURPATH/params"
	declare -p ui_state2 >> "$CURPATH/params"
	declare -p lang >> "$CURPATH/params"
	declare -p RSYNC_PASSWORD >> "$CURPATH/params"
	declare -p LOGNAME >> "$CURPATH/params"
	declare -p MD5_UPDATE >> "$CURPATH/params"
	declare -p UPDATE_ENABLE >> "$CURPATH/params"
	declare -p UI >> "$CURPATH/params"
}
    
installer_addons(){
    # DIALOG, afficher liste des addons installable (indiquer état installé?)
    echo TODO addons
	menu_principal
}
    
afficher_changelog(){
	info "Affichage changelog"
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
	--title "$changelog_title" \
	--infobox "\n$changelog1" 5 61 2> $tempfile
	$RSYNC_SIG --log-file=$LOG_RSYNC rsync://$rsyncd_host:/$rsyncd_module/Changelog.txt "$CURPATH/tmp/Changelog.txt"
	$DIALOG --backtitle "$backtitle                                                     $VERSION" \
	--title "$changelog_title" --scrollbar \
	--exit-label "OK" \
	--textbox "$CURPATH/tmp/Changelog.txt" 35 90 2> $tempfile
	menu_principal
}

changer_langue(){
	
    if [ "$lang" = "FR" ]
    then
        lang="EN"
    else
        if [ "$lang" = "EN" ]
        then
            lang="FR"
        fi
    fi
	info "Changement de langue pour $lang"
    sauver_prefs
}

sortir(){
    sauver_prefs
	info "Sortie"
	exit
}

verifier_signature(){
	# $1: fichier signature
	trap 'rapporter_erreur 2 $LINENO $?' ERR
	$RSYNC_SIG --log-file=$LOG_RSYNC rsync://$rsyncd_host:/$rsyncd_module/signatures/$1 tmp/
	trap - ERR	
	cd "$RFACTOR_PATH"
	md5sum -c "$CURPATH/tmp/$1" --strict --status
	is_nok=$?
	cd "$CURPATH"
	rm -f tmp/$1
	info "Verification signature fichier $1=$1"
	return $is_nok
}

mise_a_jour()
{
	if [ $UPDATE_ENABLE -eq 1 ]
	then
		info "Debut mise a jour"
		$DIALOG --backtitle "$backtitle                                                     $VERSION" \
		--title "$patience" \
		--infobox "\n$maj1" 5 61 2> $tempfile

	retval=$?
	
		if [ -f  "$CURPATH/tmp/script.md5" ]
		then
			$RSYNC_SIG --log-file=$LOG_RSYNC rsync://$rsyncd_host:/$rsyncd_module/ODSsync2/script.sh ./script.sh
			besoin_maj=`md5sum -c "$CURPATH/tmp/script.md5" --strict --status; echo $? `
			if [ "$besoin_maj" -eq 0 ]
			then
				info "Mise a jour non necessaire"
			else
				info "Mise a jour necessaire"
				$DIALOG --backtitle "$backtitle                                                     $VERSION" \
				--title "$patience" \
				--infobox "\n$maj2" 5 61 2> $tempfile
					
				$RSYNC_SIG --log-file=$LOG_RSYNC --files-from=:Packs/ODSsync2.sync rsync://$rsyncd_host:/$rsyncd_module/ODSsync2/ "$RFACTOR_PATH/ODSsync2/"
				md5sum "$CURPATH/script.sh" > "$CURPATH/tmp/script.md5"
				sauver_prefs
				"$RFACTOR_PATH/ODSsync2/script.sh"
				exit
			fi
			
		else
			# premier lancement, on force la maj, puis on fait le md5 du fichier update
			info "Mise a jour premier lancement"
			$RSYNC_SIG --log-file=$LOG_RSYNC --files-from=:Packs/ODSsync2.sync rsync://$rsyncd_host:/$rsyncd_module/ODSsync2/ "$RFACTOR_PATH/ODSsync2/"
			md5sum "$CURPATH/script.sh" > "$CURPATH/tmp/script.md5"
			sauver_prefs
			"$RFACTOR_PATH/ODSsync2/script.sh"
			exit
			#sortie
		fi
		info "Fin mise a jour"
	else
		info "Mise a jour desactivee"
	fi
		

}

# MAIN
info "Lancement version $VERSION, rfactor installe dans $RFACTOR_PATH"
charger_langue
verifier_mdp
mise_a_jour

if [ "$INSTALL_PATH" = "/cygdrive/c" ]
	then rapporter_erreur 11
fi
if [ "$INSTALL_PATH" = "/cygdrive/c/Program Files" ]
	then rapporter_erreur 13
fi
if [ "$INSTALL_PATH" = "/cygdrive/c/Program Files (x86)" ]
	then rapporter_erreur 13
fi

ps -aW | grep rFactor.exe 1>/dev/null
is_rfactor_running=`echo $?`
if [ $is_rfactor_running -eq 0 ]
	then rapporter_erreur 12
fi

verifier_signature '1.md5'
if [ $? -eq 0 ]
then
	info "Mod blender installe, lancement menu principal"
	rfe=`rfe_etat;echo $?`
	menu_principal "firsttime"
else
	about
	info "Mod blender non installe"
	choisir_langue
	neufcinq=`verifier_signature '2.md5'; echo $? `
	neufcinqods=`verifier_signature '3.md5' ; echo $? `
	neufsix=`verifier_signature '31.md5' ; echo $? `
	if [ "$neufcinq" -eq 0 ] || [ "$neufcinqods" -eq 0 ] || [ "$neufsix" -eq 0 ]
	then
		blender_install
	else
		if [ -d "$RFACTOR_PATH/GameData/Vehicles/HISTORIC GT/HISTORICAL FIA GT/GTC-TC-76/JAVELIN/" ]
		then
			blender_preinstall_done
		else
			blender_preinstall
		fi
	fi
        
fi